@@ -18,7 +18,6 @@
 # along with Ansible.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-import ConfigParser
 import json
 import os
 import re
@@ -29,7 +28,9 @@ import inspect
 
 from packaging.version import Version
 from os.path import expanduser
-from ansible.module_utils.basic import *
+
+from ansible.module_utils.basic import AnsibleModule
+from ansible.module_utils.six.moves import configparser
 
 AZURE_COMMON_ARGS = dict(
     profile=dict(type='str'),
@@ -311,7 +312,7 @@ class AzureRMModuleBase(object):
     def _get_profile(self, profile="default"):
         path = expanduser("~/.azure/credentials")
         try:
-            config = ConfigParser.ConfigParser()
+            config = configparser.ConfigParser()
             config.read(path)
         except Exception as exc:
             self.fail("Failed to access {0}. Check that the file exists and you have read "
@@ -345,7 +346,7 @@ class AzureRMModuleBase(object):
     def _get_credentials(self, params):
         # Get authentication credentials.
         # Precedence: module parameters-> environment variables-> default profile in ~/.azure/credentials.
-        
+
         self.log('Getting credentials')
 
         arg_credentials = dict()
@@ -357,11 +358,11 @@ class AzureRMModuleBase(object):
             self.log('Retrieving credentials with profile parameter.')
             credentials = self._get_profile(arg_credentials['profile'])
             return credentials
-        
+
         if arg_credentials['subscription_id']:
             self.log('Received credentials from parameters.')
             return arg_credentials
-        
+
         # try environment
         env_credentials = self._get_env_credentials()
         if env_credentials:
@@ -387,11 +388,11 @@ class AzureRMModuleBase(object):
         '''
         dependencies = dict()
         if enum_modules:
-            for module_name in enum_modules:  
-               mod = importlib.import_module(module_name)
-               for mod_class_name, mod_class_obj in inspect.getmembers(mod, predicate=inspect.isclass):
-                   dependencies[mod_class_name] = mod_class_obj 
-            self.log("dependencies: ");
+            for module_name in enum_modules:
+                mod = importlib.import_module(module_name)
+                for mod_class_name, mod_class_obj in inspect.getmembers(mod, predicate=inspect.isclass):
+                    dependencies[mod_class_name] = mod_class_obj
+            self.log("dependencies: ")
             self.log(str(dependencies))
         serializer = Serializer(classes=dependencies)
         return serializer.body(obj, class_name)
@@ -579,7 +580,11 @@ class AzureRMModuleBase(object):
             resource_client = self.rm_client
             resource_client.providers.register(key)
         except Exception as exc:
-            self.fail("One-time registration of {0} failed - {1}".format(key, str(exc)))
+            self.log("One-time registration of {0} failed - {1}".format(key, str(exc)))
+            self.log("You might need to register {0} using an admin account".format(key))
+            self.log(("To register a provider using the Python CLI: "
+                      "https://docs.microsoft.com/azure/azure-resource-manager/"
+                      "resource-manager-common-deployment-errors#noregisteredproviderfound"))
 
     @property
     def storage_client(self):
