@@ -38,9 +38,6 @@ class ActionModule(ActionBase):
 
         result = super(ActionModule, self).run(tmp, task_vars)
 
-        if result.get('skipped', False):
-            return result
-
         module = self._task.args.get('use', 'auto')
 
         if module == 'auto':
